WindowOrDissimilarOriginWindow

Enum WindowOrDissimilarOriginWindow 

enum WindowOrDissimilarOriginWindow {
    Window(DomRoot<Window>),
    DissimilarOriginWindow(DomRoot<DissimilarOriginWindow>),
}
A wrapper class for either a Window or DissimilarOriginWindow that exposes a consistent interface for both of them.

Variants



Window(DomRoot<Window>)



DissimilarOriginWindow(DomRoot<DissimilarOriginWindow>)

Implementations

Source

impl WindowOrDissimilarOriginWindow

fn new(cx: &mut JSContext, handle_object: HandleObject<'_>) -> Self

fn global_scope(&self) -> DomRoot<GlobalScope>

fn window_proxy(&self) -> DomRoot<WindowProxy>

fn cross_origin_properties(&self) -> &'static CrossOriginProperties

fn iframe_count(&self) -> u32

fn window_proxy_for_child_navigable_at_index( &self, index: u32, ) -> Option<DomRoot<WindowProxy>>

fn named_child_navigable( &self, cx: &mut CurrentRealm<'_>, id: HandleId<'_>, ) -> Option<DomRoot<WindowProxy>>

https://html.spec.whatwg.org/multipage/#document-tree-child-navigable-target-name-property-set

The document-tree child navigable target name property set of a Window object window is the return value of running these steps:

Step 1. Let children be the document-tree child navigables of window’s associated Document. Step 2. Let firstNamedChildren be an empty ordered set. Step 3. For each navigable of children: Step 3.1. Let name be navigable’s target name. Step 3.2. If name is the empty string, then continue. Step 3.3. If firstNamedChildren contains a navigable whose target name is name, then continue. Step 3.4. Append navigable to firstNamedChildren. Step 4. Let names be an empty ordered set. Step 5. For each navigable of firstNamedChildren: Step 5.1. Let name be navigable’s target name. Step 5.2. If navigable’s active document’s origin is same origin with window’s relevant settings object’s origin, then append name to names. Step 6. Return names.

We don’t implement these steps exactly, but we effectively do them using iterators below.